pub enum InputState {
Keyboard(KeyboardInputState),
Mouse(MouseInputState),
}Expand description
An input state obtained by reading an InputDevice.
This InputState may either be a Keyboard or a Mouse
depending on what kind of device the InputDevice it was read from is.
To get a KeyboardInputState or MouseInputState without having to match this enum,
consider narrowing down the type of device by matching the InputDevice instead,
which will give you a KeyboardDevice or MouseDevice which, when read,
will give you the appropriate kind of input state directly.
Variants
Keyboard(KeyboardInputState)
An input state coming from a keyboard.
Mouse(MouseInputState)
An input state coming from a mouse.
Implementations
Sourceimpl InputState
impl InputState
Sourcepub fn keyboard(self) -> Option<KeyboardInputState>
pub fn keyboard(self) -> Option<KeyboardInputState>
Turns this InputState into an Option<KeyboardInputState>.
Similarly to Result::ok, this will consume self and discard the inner value if it was a Mouse.
Sourcepub fn mouse(self) -> Option<MouseInputState>
pub fn mouse(self) -> Option<MouseInputState>
Turns this InputState into an Option<MouseInputState>.
Similarly to Result::ok, this will consume self and discard the inner value if it was a Keyboard.
Sourcepub fn is_keyboard(&self) -> bool
pub fn is_keyboard(&self) -> bool
Returns whether this InputState is a Keyboard.